package com.zhentao.moment.config;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;

@ConfigurationProperties(prefix = "aliyun.oss")
@Data
public class OssProperties {

    /**
     * OSS Endpoint
     */
    private String endpoint;

    /**
     * AccessKey ID
     */
    private String accessKeyId;

    /**
     * AccessKey Secret
     */
    private String accessKeySecret;

    /**
     * Bucket名称
     */
    private String bucketName;

    /**
     * 上传配置
     */
    private Upload upload = new Upload();

    /**
     * 上传配置内部类
     */
    @Data
    public static class Upload {

        /**
         * 图片上传配置
         */
        private Image image = new Image();

        /**
         * 视频上传配置
         */
        private Video video = new Video();

        /**
         * 图片上传配置内部类
         */
        @Data
        public static class Image {

            /**
             * 图片上传目录
             */
            private String dir = "moments/images/";

            /**
             * 图片最大大小(字节)，默认10MB
             */
            private long maxSize = 10 * 1024 * 1024;
        }

        /**
         * 视频上传配置内部类
         */
        @Data
        public static class Video {

            /**
             * 视频上传目录
             */
            private String dir = "moments/videos/";

            /**
             * 视频最大大小(字节)，默认50MB
             */
            private long maxSize = 50 * 1024 * 1024;
        }
    }
}
